#
# spec file for package libqmatrixclient
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


#
%define soname libQMatrixClient
%define soversion 0_5_3
%define sname libQuotient

Name:           libqmatrixclient
Version:        0.5.3.2
Release:        bp156.2.5
Summary:        Library for Qt Matrix Clients
License:        LGPL-2.1-only
Group:          Development/Libraries/C and C++
URL:            https://github.com/quotient-im/libQuotient/
Source0:        https://github.com/quotient-im/libQuotient/archive/%{version}/%{name}-%{version}.tar.gz
# Old SourceUrl for documentation.
#Source0:        https://github.com/QMatrixClient/libqmatrixclient/archive/%%{version}/%%{name}-%%{version}.tar.gz
BuildRequires:  cmake
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(Qt5Core) >= 5.6
BuildRequires:  pkgconfig(Qt5Gui)
BuildRequires:  pkgconfig(Qt5Multimedia)
BuildRequires:  pkgconfig(Qt5Network)
%if 0%{?suse_version} < 1500
BuildRequires:  gcc7-c++
%else
BuildRequires:  gcc-c++
%endif

%description
Library for Qt-based Matrix chat clients. It is required by
Quaternion.

%package -n %{soname}%{soversion}
Summary:        Library for Qt Matrix Clients
Group:          System/Libraries

%description -n %{soname}%{soversion}
Library for Qt-based Matrix chat clients. It is required by
Quaternion.

%package devel
Summary:        Development files for %{name}
Group:          Development/Libraries/C and C++
Requires:       %{soname}%{soversion} = %{version}

%description devel
The %{name}-devel package contains libraries and header files for
developing applications that use %{name}.

%prep
%setup -q -n %{sname}-%{version}

%build
%if 0%{?suse_version} < 1500
export CC="gcc-7"
export CXX="g++-7"
%endif
%cmake \
   -DCMAKE_INSTALL_INCLUDEDIR=%{_includedir}/%{name} \
   -DBUILD_SHARED_LIBS=ON

%install
%cmake_install
# need for other clients like quaternion
mkdir -p %{buildroot}%{_datadir}/QMatrixClient

%post  -n %{soname}%{soversion} -p /sbin/ldconfig
%postun -n %{soname}%{soversion} -p /sbin/ldconfig

%files -n %{soname}%{soversion}
%doc README.md
%license COPYING
%dir %{_datadir}/QMatrixClient
%{_libdir}/libQMatrixClient.so.*

%files devel
%doc README.md
%license COPYING
%{_libdir}/pkgconfig/QMatrixClient.pc
%{_libdir}/libQMatrixClient.so
%{_libdir}/cmake/QMatrixClient/
%{_includedir}/%{name}
%{_bindir}/qmc-example

%changelog
* Wed Apr  1 2020 ecsos@opensuse.org
- Update to 0.5.3.2
  This is the same as 0.5.3.1, except the API version
  (aka soversion) bumped to 0.5.3 to ensure correct upgrade via
  Quaternion dependencies.
* Tue Mar 31 2020 ecsos@opensuse.org
- Update to 0.5.3.1
  One more "sustaining" release that fixes a long-standing problem
  with job objects lifetime lasting beyond their connection
  lifetime, leading to crashes on connection removal (#397/#398).
  This problem became very apparent with introduction of SSO in
  Quaternion, where connection objects are removed as soon as the
  login dialog is cancelled; this release is aimed solely at fixing
  that.
* Mon Mar 30 2020 ecsos@opensuse.org
- Update to 0.5.3
  - (#301/#383) Room::aliases() and Room::setAliases() are fixed,
    using the new alias management introduced in MSC2432
  - (#321) More careful linkification of Matrix ids
  - (#326) Support for the server notices room tag (MSC1452)
  - (#330) Support of resolving the homeserver using .well-known
    (MSC433)
  - (#341/#373/#376) Support of message editing and annotation
    (MSC1849)
  - (#344) Compatibility with user deactivation error codes
    (MSC2181)
  - (#345) Fix cache becoming inconsistent with actual room state
    due to unread counts not properly tracked
  - (#347) Fix for a corner case in internal user avatar management
    that may lead to a crash in rare cases
  - (#354) Provide a means to get the full list of rooms to client
    applications (aimed at fixing quotient-im/Quaternion#637 in the
    next Quaternion 0.0.9.4 rebuild)
  - (#358) Only send access token where the spec it should be sent
  - (#359) Fix room highlighting for names with a hashtag
  - (#361) Initialise read marker if there's none on the room yet
  - (#365) Remove prev_content from special keys preserved against
    redaction (MSC1954) - thanks to nepugia for reporting
  - (#387) Compatibility with Qt 5.14
  - (#386/#388) SSO support
  - (#390) Notify the client application about alias updates
- The name of the library in this branch is still libQMatrixClient.
  Version 0.6 will be named libQuotient, as announced previously.
- Drop 0001-Compatibility-with-Qt-5.14.patch because no more
  necessary.
* Wed Jan 29 2020 ecsos@opensuse.org
- Update to 0.5.2
  This is the last version of libqmatrixclient.
  Only for quaternion and other packages wich need that.
  Problem is that libqmatrixclient was renamed, but quaternion from
  same developer use still old libnames.
- Add 0001-Compatibility-with-Qt-5.14.patch from upstream.
* Thu Apr 18 2019 ecsos@opensuse.org
- Update to 0.5.1.2
  - (#316) Expired tokens no more bring IncorrectRequestError
    instead of ContentAccessError; consequently,
    Connection::logout() ignores ContentAccessErrors so expired
    tokens don't leave the library in a "can't go-in, can't go out"
    state.
  - Jobs abandoned due to Connection being deleted no more cause
    crashes.
- Run spec-cleaner.
* Sat Apr  6 2019 ecsos@opensuse.org
- Update to 0.5.1.1
  This release fixes a bug that makes 0.5.1 not being "new enough"
  for Quaternion 0.0.9.4, and another bug that made user showing up
  multiple times in the user list of Quaternion after renaming.
  Otherwise it's the same as version 0.5.1.
* Fri Apr  5 2019 ecsos@opensuse.org
- Update to 0.5.1
  - Fix (#303): linkification doesn't break on peculiar links.
  - Fix (#310 and 27c2989): quirks in rendering room display names
    have been ironed out.
  - Fix: Tighter validations of URLs coming with file events
    (too relaxed validations were causing the library to
    assert-crash on, e.g., encrypted attachments).
  - Enhancement (#305): rooms created as direct chats are now
    automatically marked as m.direct for invited as well as
    inviting users.
  - Enhancement (#306): Room::canSwitchVersions() returns false on
    rooms already upgraded (you still can disregard and call
    Room::switchVersion() but you better think twice
  - see matrix-org/matrix-doc#1937).
  - Enhancement: Room::postFile() now first starts file upload and
    then places a pending event (neatly packed with file transfer
    information), rather than the other way around. Unless you do
    weird things with the library's API, you shouldn't notice.
  - Enhancement: LRO/RLO Unicode markers are now stripped from
    display names, to curtail abuse of those.
  - Feature: Connection::domain() to save client authors from
    taking the domain from user MXID.
* Wed Apr  3 2019 ecsos@opensuse.org
- Update to 0.5.0.2
  * Another bugfix release in 0.5.x branch, fixing issues with
    sending read receipts and redactions in v3 rooms (#300).
- Changes from 0.5.0.1
  * This version fixes too stringent checks in debug builds that
    led to assertion crashes upon encounter with upgraded rooms.
- Changes from 0.5
  As usual for 0.x versions, 0.5 breaks API compatibility with
  previous versions; 0.4-compatible clients may or may not need
  changes in order to compile with version 0.5. As usual, see diffs
  in header files to track the changes and update the client code
  accordingly; these release notes highlight most prominent API
  changes.
  Micro-versions in 0.5.y will maintain the API and ABI.
  Version 0.6 will break either API or ABI or both.
  Over 200 commits. So see for changelog
  https://github.com/QMatrixClient/libqmatrixclient/commits/0.5.0
* Sun Jan 13 2019 Michael Vetter <mvetter@suse.com>
- Update to 0.4.2.1:
  * No more treat fake state events (that don't have
    state_key, even if they have state-related type, e.g., m.room.topic)
    as state events, turning them into unknown events instead.
* Sun Dec 16 2018 Michael Vetter <mvetter@suse.com>
- Update to 0.4.1
  * Fix pending events (aka local echo) not being cleaned up
    properly
  * Fix rooms not being correctly sorted according to their
    position under tag if using Connection::roomsByTags()
  * Fix incorrect SOVERSION
* Fri Nov  9 2018 ecsos@opensuse.org
- Remove soname from devel.
* Wed Nov  7 2018 Jan Engelhardt <jengelh@inai.de>
- Edit RPM groups.
* Tue Oct 16 2018 ecsos@opensuse.org
- update to 0.4.0
  So many changes and no propoer changelog from upstream.
  See changes here:
  https://github.com/QMatrixClient/libqmatrixclient/compare/v0.3.0.2...v0.4.0
* Mon Aug 20 2018 ecsos@opensuse.org
- update to 0.3.0.2
  So many changes and no proper changelog from upstream.
  See changes here:
  https://github.com/QMatrixClient/libqmatrixclient/compare/v0.2.1...v0.3.0.2
* Wed May  2 2018 ecsos@opensuse.org
- update to 0.2.1
  - Fixed an occasional crash due to dangling callbacks in avatar
    fetching code
  - Fixed unreliable network error handling leading to sync loop
    getting "unlooped" when server is temporarily unavailable
  - Fixed a regression leading to bridge postfixes not being
    removed from user display names
  - Fixed a regression manifesting in dysfunctional user name
    disambiguation
  - Added User::rawName() to get a user name together with its
    bridge postfix
  - Bridge names are now used as the first line of disambiguation,
    with user ids being the next (and ultimate) fallback.
- remove service file
* Thu Apr 12 2018 agraul@suse.com
- remove remove_unwanted_cmake_installations.patch
  * upstream remove EXPORT_ANDROID_MK from install targets
- use service to download sources from github
* Tue Apr  3 2018 agraul@suse.com
- add remove_unwanted_cmake_installations.patch
  * this patch removes cmake install targets that are not
    targeted at linux
- cleanup spec file
* Mon Apr  2 2018 agraul@suse.com
- update to 0.2rc
- fix build
* Mon Jan  1 2018 agraul@suse.com
- add cmake_install_target.patch
* Mon Jan  1 2018 agraul@suse.com
- update to 0.2-q0.0.5
* Fri Nov 10 2017 agraul@suse.com
- inital package
